CTAppend

Trait CTAppend 

pub trait CTAppend<X> {
    type Output: CTCons;
}
Trait used to append items to compile time structure.

Cast the parent structure as CTAppend whith the addition as generic argument. If this trait is implemented for the parent structure, CTAppend::Output will hold the resulting type.

Example

type ExampleTwo = <<CTConsTerm as CTAppend<u8>>::Output as CTAppend<u32>>::Output;

Required Associated Types

type Output: CTCons

The new compile time structure which consists of the implemented structure with X as new item.

Implementors

Source

impl<X> CTAppend<X> for CTConsTerm
where X: 'static,

Source

impl<X, Tail, Head> CTAppend<X> for Cons<Tail, Head>
where X: 'static, Tail: CTCons + 'static, Head: 'static,

Source

type Output = Cons<Cons<Tail, Head>, X>