pub struct Cons<Tail, Head>where
Tail: CTCons,{ /* private fields */ }Expand description
Actual type used to carry cons list information.
This type is useful to create a new cons list in a compact syntax, like the example within the module documentation. Other than for creating new cons lists this structure isn’t useful.