pub trait CTAppend<X> {
type Output: CTCons;
}Expand description
Trait used to append items to compile time structure.
Cast the parent structure as CTAppend whith the addition as generic argument.
If this trait is implemented for the parent structure, CTAppend::Output will
hold the resulting type.
Example
type ExampleTwo = <<CTConsTerm as CTAppend<u8>>::Output as CTAppend<u32>>::Output;