pub trait CTCons {
type Head: 'static;
type Tail: CTCons + 'static;
}Expand description
Represents a cons list where each new addition builds further onto the previous list.
The previous list is at CTCons::Tail and CTConsTerm is used as bootstrapper
to create the initial tail.
The latest item is at CTCons::Head.
Use CTAppend to add new types to the cons list.
Preconditions
- The cons list MUST NOT contain multiple items of the exact same type. This will result
in wrong offsets.
Type X and Type Y are considered exactly the same if their TypeId match. eg
std::any::TypeId::of::<X> == std::any::TypeId::of::<Y>Seestd::any::TypeId.