pub struct IfCheck<X> { /* private fields */ }Expand description
Actual type used to perform an IF check through the type system.
Performing an IF test through the type system requires both this structure as well
as the CTIf trait (or a specialized one). The typed that needs to be matched
is passed into this struct as generic argument for X.
The resulting type must then be cast as CTIf trait, which includes the desired type.
CTIf::Path will then hold the match relevant type.
eg
ⓘ
<IfCheck<Subject> as CTIf<Desired, TypeTrue, TypeFalse>>::Path;Trait Implementations
Sourceimpl<X, CondFail, OptionTrue, OptionFalse> CTIf<CondFail, OptionTrue, OptionFalse> for IfCheck<X>
impl<X, CondFail, OptionTrue, OptionFalse> CTIf<CondFail, OptionTrue, OptionFalse> for IfCheck<X>
Sourceimpl<X, CondFail, OptionTrue, OptionFalse> CTIfOffset<CondFail, OptionTrue, OptionFalse> for IfCheck<X>
impl<X, CondFail, OptionTrue, OptionFalse> CTIfOffset<CondFail, OptionTrue, OptionFalse> for IfCheck<X>